@@ -6,9 +6,11 @@ from abc import abstractmethod
 import traceback
 from typing import Optional, Tuple, Union
 
+
 from ..mbta_object_store import MBTARouteObjStore, MBTAStopObjStore
 
 from ..client.mbta_client import MBTAClient
+from ..client.mbta_cache_manager import MBTACacheManager
 
 from ..trip import Trip
 from ..stop import Stop, StopType
@@ -39,11 +41,7 @@ class MBTABaseHandler:
         self._mbta_trip_stops_ids = set()
 
         #self._trips: dict[str, Trip] = {}  # Dictionary to store Trip objects, keyed by trip ID
-
-        self._last_processed_scheduling = {
-             'data': None,
-             'timestamp': None
-        }
+        self._cache_manager = MBTACacheManager()
 
         self._logger = logger or logging.getLogger(__name__)  # Logger instance
 
@@ -124,30 +122,52 @@ class MBTABaseHandler:
 
         try:
 
-            ####
-            params_predictions = None
-            if params and "filter[date]" in params.keys():
-                params_predictions = params.copy()
-                del params_predictions["filter[date]"]
-            ####
-
             task_schedules = asyncio.create_task(self.__fetch_schedules(params))
-            task_predictions = asyncio.create_task(self.__fetch_predictions(params_predictions))
+   
+            task_predictions = None
+            
+            if params and ("filter[date]" in params.keys() or "filter[min_time]" in params.keys()):
+                params_predictions = params.copy()
+                
+                if "filter[min_time]" in params.keys():
+                    del params_predictions["filter[min_time]"]
+                
+                if "filter[date]" in params.keys():
+                    del params_predictions["filter[date]"]
+                    if datetime.fromisoformat(params['filter[date]']).date() == datetime.now().date():
+                        task_predictions = asyncio.create_task(self.__fetch_predictions(params_predictions))
+                else:
+                    task_predictions = asyncio.create_task(self.__fetch_predictions(params_predictions))
+            
+            else:
+                task_predictions = asyncio.create_task(self.__fetch_predictions(params))
 
             mbta_schedules, timestamp = await task_schedules
-
-            if self._last_processed_scheduling['timestamp'] != timestamp:
-                self._logger.debug("New MBTA schedules data detected. Processing...")
-                trips = await self.__process_scheduling(schedulings=mbta_schedules,trips=trips)
-                self._last_processed_scheduling['data'] = trips
-                self._last_processed_scheduling['timestamp'] = timestamp
+            
+            ## UGLY! using improperly the cache manager to store processed schedule, 
+            cached_data, _, cached_timestamp = self._cache_manager.get_cached_data(path=params,params=None)
+            
+            if cached_timestamp == timestamp:
+                self._logger.debug("MBTA schedules data are up-to-date. Skipp processing.")
+                trips = cached_data
             else:
-                self._logger.debug("MBTA Schedules data are up-to-date. Skipping processing.")
-                trips = self._last_processed_scheduling['data']
+                self._logger.debug("New MBTA schedules data detected. Processing.")
+                trips = await self.__process_scheduling(schedulings=mbta_schedules,trips=trips)
+                self._cache_manager.update_cache(path=params,params=None,data=trips,last_modified=timestamp)
+            
+            # if self._last_processed_scheduling['timestamp'] != timestamp:
+            #     self._logger.debug("New MBTA schedules data detected. Processing...")
+            #     trips = await self.__process_scheduling(schedulings=mbta_schedules,trips=trips)
+            #     self._last_processed_scheduling['data'] = trips
+            #     self._last_processed_scheduling['timestamp'] = timestamp
+            # else:
+            #     self._logger.debug("MBTA Schedules data are up-to-date. Skipping processing.")
+            #     trips = self._last_processed_scheduling['data']
 
-            mbta_predictions, _ = await task_predictions
+            if task_predictions:
+                mbta_predictions, _ = await task_predictions
 
-            trips = await self.__process_scheduling(schedulings=mbta_predictions, trips=trips)
+                trips = await self.__process_scheduling(schedulings=mbta_predictions, trips=trips)
 
             return trips
 
